pip
===

A tool for installing and managing Python packages.

`User list <http://groups.google.com/group/python-virtualenv>`_ |
`Dev list <http://groups.google.com/group/pypa-dev>`_ |
`Issues <https://github.com/pypa/pip/issues>`_ |
`Github <https://github.com/pypa/pip>`_ |
`PyPI <https://pypi.python.org/pypi/pip/>`_ |
irc:#pip


.. toctree::
   :maxdepth: 2

   quickstart
   installing
   usage
   cookbook
   logic
   configuration
   other-tools
   development
   news

